<?php

declare(strict_types=1);

namespace Drupal\schemadotorg\Form;

use Drupal\Core\Form\FormStateInterface;

/**
 * Configure Schema.org general settings for types.
 */
class SchemaDotOrgSettingsGeneralForm extends SchemaDotOrgSettingsFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'schemadotorg_general_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['schemadotorg.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config('schemadotorg.settings');
    $form['schema_general'] = [
      '#type' => 'details',
      '#title' => $this->t('General settings'),
    ];
    $form['schema_general']['recommended_modules'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Check for recommended modules'),
      '#description' => $this->t('If checked, recommended modules that help integrate and support Schema.org mappings, entities, and fields will be checked for and a warning will be displayed if they are missing.'),
      '#return_value' => TRUE,
      '#default_value' => $config->get('recommended_modules'),
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $config = $this->config('schemadotorg.settings');
    $values = $form_state->getValue('schema_general');
    foreach ($values as $key => $value) {
      $config->set($key, $value);
    }
    $config->save();
    parent::submitForm($form, $form_state);
  }

}
